@@ -1,9 +1,7 @@
 import numpy as np
 
 
-def preprocess_input(
-    x, mean=None, std=None, input_space="RGB", input_range=None, **kwargs
-):
+def preprocess_input(x, mean=None, std=None, input_space="RGB", input_range=None, **kwargs):
 
     if input_space == "BGR":
         x = x[..., ::-1].copy()
