@@ -11,7 +11,7 @@ from ._base import EncoderMixin
 
 
 def get_efficientnet_kwargs(channel_multiplier=1.0, depth_multiplier=1.0, drop_rate=0.2):
-    """Creates an EfficientNet model.
+    """Create EfficientNet model.
     Ref impl: https://github.com/tensorflow/tpu/blob/master/models/official/efficientnet/efficientnet_model.py
     Paper: https://arxiv.org/abs/1905.11946
     EfficientNet params
@@ -31,13 +31,13 @@ def get_efficientnet_kwargs(channel_multiplier=1.0, depth_multiplier=1.0, drop_r
       depth_multiplier: multiplier to number of repeats per stage
     """
     arch_def = [
-        ['ds_r1_k3_s1_e1_c16_se0.25'],
-        ['ir_r2_k3_s2_e6_c24_se0.25'],
-        ['ir_r2_k5_s2_e6_c40_se0.25'],
-        ['ir_r3_k3_s2_e6_c80_se0.25'],
-        ['ir_r3_k5_s1_e6_c112_se0.25'],
-        ['ir_r4_k5_s2_e6_c192_se0.25'],
-        ['ir_r1_k3_s1_e6_c320_se0.25'],
+        ["ds_r1_k3_s1_e1_c16_se0.25"],
+        ["ir_r2_k3_s2_e6_c24_se0.25"],
+        ["ir_r2_k5_s2_e6_c40_se0.25"],
+        ["ir_r3_k3_s2_e6_c80_se0.25"],
+        ["ir_r3_k5_s1_e6_c112_se0.25"],
+        ["ir_r4_k5_s2_e6_c192_se0.25"],
+        ["ir_r1_k3_s1_e6_c320_se0.25"],
     ]
     model_kwargs = dict(
         block_args=decode_arch_def(arch_def, depth_multiplier),
@@ -50,8 +50,9 @@ def get_efficientnet_kwargs(channel_multiplier=1.0, depth_multiplier=1.0, drop_r
     )
     return model_kwargs
 
+
 def gen_efficientnet_lite_kwargs(channel_multiplier=1.0, depth_multiplier=1.0, drop_rate=0.2):
-    """Creates an EfficientNet-Lite model.
+    """EfficientNet-Lite model.
 
     Ref impl: https://github.com/tensorflow/tpu/tree/master/models/official/efficientnet/lite
     Paper: https://arxiv.org/abs/1905.11946
@@ -69,13 +70,13 @@ def gen_efficientnet_lite_kwargs(channel_multiplier=1.0, depth_multiplier=1.0, d
       depth_multiplier: multiplier to number of repeats per stage
     """
     arch_def = [
-        ['ds_r1_k3_s1_e1_c16'],
-        ['ir_r2_k3_s2_e6_c24'],
-        ['ir_r2_k5_s2_e6_c40'],
-        ['ir_r3_k3_s2_e6_c80'],
-        ['ir_r3_k5_s1_e6_c112'],
-        ['ir_r4_k5_s2_e6_c192'],
-        ['ir_r1_k3_s1_e6_c320'],
+        ["ds_r1_k3_s1_e1_c16"],
+        ["ir_r2_k3_s2_e6_c24"],
+        ["ir_r2_k5_s2_e6_c40"],
+        ["ir_r3_k3_s2_e6_c80"],
+        ["ir_r3_k5_s1_e6_c112"],
+        ["ir_r4_k5_s2_e6_c192"],
+        ["ir_r1_k3_s1_e6_c320"],
     ]
     model_kwargs = dict(
         block_args=decode_arch_def(arch_def, depth_multiplier, fix_first_last=True),
@@ -89,8 +90,8 @@ def gen_efficientnet_lite_kwargs(channel_multiplier=1.0, depth_multiplier=1.0, d
     )
     return model_kwargs
 
-class EfficientNetBaseEncoder(EfficientNet, EncoderMixin):
 
+class EfficientNetBaseEncoder(EfficientNet, EncoderMixin):
     def __init__(self, stage_idxs, out_channels, depth=5, **kwargs):
         super().__init__(**kwargs)
 
@@ -105,10 +106,10 @@ class EfficientNetBaseEncoder(EfficientNet, EncoderMixin):
         return [
             nn.Identity(),
             nn.Sequential(self.conv_stem, self.bn1, self.act1),
-            self.blocks[:self._stage_idxs[0]],
-            self.blocks[self._stage_idxs[0]:self._stage_idxs[1]],
-            self.blocks[self._stage_idxs[1]:self._stage_idxs[2]],
-            self.blocks[self._stage_idxs[2]:],
+            self.blocks[: self._stage_idxs[0]],
+            self.blocks[self._stage_idxs[0] : self._stage_idxs[1]],
+            self.blocks[self._stage_idxs[1] : self._stage_idxs[2]],
+            self.blocks[self._stage_idxs[2] :],
         ]
 
     def forward(self, x):
@@ -128,15 +129,29 @@ class EfficientNetBaseEncoder(EfficientNet, EncoderMixin):
 
 
 class EfficientNetEncoder(EfficientNetBaseEncoder):
-
-    def __init__(self, stage_idxs, out_channels, depth=5, channel_multiplier=1.0, depth_multiplier=1.0, drop_rate=0.2):
+    def __init__(
+        self,
+        stage_idxs,
+        out_channels,
+        depth=5,
+        channel_multiplier=1.0,
+        depth_multiplier=1.0,
+        drop_rate=0.2,
+    ):
         kwargs = get_efficientnet_kwargs(channel_multiplier, depth_multiplier, drop_rate)
         super().__init__(stage_idxs, out_channels, depth, **kwargs)
 
 
 class EfficientNetLiteEncoder(EfficientNetBaseEncoder):
-
-    def __init__(self, stage_idxs, out_channels, depth=5, channel_multiplier=1.0, depth_multiplier=1.0, drop_rate=0.2):
+    def __init__(
+        self,
+        stage_idxs,
+        out_channels,
+        depth=5,
+        channel_multiplier=1.0,
+        depth_multiplier=1.0,
+        drop_rate=0.2,
+    ):
         kwargs = gen_efficientnet_lite_kwargs(channel_multiplier, depth_multiplier, drop_rate)
         super().__init__(stage_idxs, out_channels, depth, **kwargs)
 
@@ -152,7 +167,6 @@ def prepare_settings(settings):
 
 
 timm_efficientnet_encoders = {
-
     "timm-efficientnet-b0": {
         "encoder": EfficientNetEncoder,
         "pretrained_settings": {
@@ -168,7 +182,6 @@ timm_efficientnet_encoders = {
             "drop_rate": 0.2,
         },
     },
-
     "timm-efficientnet-b1": {
         "encoder": EfficientNetEncoder,
         "pretrained_settings": {
@@ -184,7 +197,6 @@ timm_efficientnet_encoders = {
             "drop_rate": 0.2,
         },
     },
-
     "timm-efficientnet-b2": {
         "encoder": EfficientNetEncoder,
         "pretrained_settings": {
@@ -200,7 +212,6 @@ timm_efficientnet_encoders = {
             "drop_rate": 0.3,
         },
     },
-
     "timm-efficientnet-b3": {
         "encoder": EfficientNetEncoder,
         "pretrained_settings": {
@@ -216,7 +227,6 @@ timm_efficientnet_encoders = {
             "drop_rate": 0.3,
         },
     },
-
     "timm-efficientnet-b4": {
         "encoder": EfficientNetEncoder,
         "pretrained_settings": {
@@ -232,7 +242,6 @@ timm_efficientnet_encoders = {
             "drop_rate": 0.4,
         },
     },
-
     "timm-efficientnet-b5": {
         "encoder": EfficientNetEncoder,
         "pretrained_settings": {
@@ -248,7 +257,6 @@ timm_efficientnet_encoders = {
             "drop_rate": 0.4,
         },
     },
-
     "timm-efficientnet-b6": {
         "encoder": EfficientNetEncoder,
         "pretrained_settings": {
@@ -264,7 +272,6 @@ timm_efficientnet_encoders = {
             "drop_rate": 0.5,
         },
     },
-
     "timm-efficientnet-b7": {
         "encoder": EfficientNetEncoder,
         "pretrained_settings": {
@@ -280,7 +287,6 @@ timm_efficientnet_encoders = {
             "drop_rate": 0.5,
         },
     },
-
     "timm-efficientnet-b8": {
         "encoder": EfficientNetEncoder,
         "pretrained_settings": {
@@ -295,7 +301,6 @@ timm_efficientnet_encoders = {
             "drop_rate": 0.5,
         },
     },
-
     "timm-efficientnet-l2": {
         "encoder": EfficientNetEncoder,
         "pretrained_settings": {
@@ -309,7 +314,6 @@ timm_efficientnet_encoders = {
             "drop_rate": 0.5,
         },
     },
-
     "timm-tf_efficientnet_lite0": {
         "encoder": EfficientNetLiteEncoder,
         "pretrained_settings": {
@@ -323,7 +327,6 @@ timm_efficientnet_encoders = {
             "drop_rate": 0.2,
         },
     },
-
     "timm-tf_efficientnet_lite1": {
         "encoder": EfficientNetLiteEncoder,
         "pretrained_settings": {
@@ -337,7 +340,6 @@ timm_efficientnet_encoders = {
             "drop_rate": 0.2,
         },
     },
-
     "timm-tf_efficientnet_lite2": {
         "encoder": EfficientNetLiteEncoder,
         "pretrained_settings": {
@@ -351,7 +353,6 @@ timm_efficientnet_encoders = {
             "drop_rate": 0.3,
         },
     },
-
     "timm-tf_efficientnet_lite3": {
         "encoder": EfficientNetLiteEncoder,
         "pretrained_settings": {
@@ -365,7 +366,6 @@ timm_efficientnet_encoders = {
             "drop_rate": 0.3,
         },
     },
-
     "timm-tf_efficientnet_lite4": {
         "encoder": EfficientNetLiteEncoder,
         "pretrained_settings": {
