@@ -8,7 +8,6 @@ from ._base import EncoderMixin
 
 
 class XceptionEncoder(Xception, EncoderMixin):
-
     def __init__(self, out_channels, *args, depth=5, **kwargs):
         super().__init__(*args, **kwargs)
 
@@ -22,9 +21,10 @@ class XceptionEncoder(Xception, EncoderMixin):
 
         del self.fc
 
-    def make_dilated(self, stage_list, dilation_list):
-        raise ValueError("Xception encoder does not support dilated mode "
-                         "due to pooling operation for downsampling!")
+    def make_dilated(self, *args, **kwargs):
+        raise ValueError(
+            "Xception encoder does not support dilated mode " "due to pooling operation for downsampling!"
+        )
 
     def get_stages(self):
         return [
@@ -32,8 +32,17 @@ class XceptionEncoder(Xception, EncoderMixin):
             nn.Sequential(self.conv1, self.bn1, self.relu, self.conv2, self.bn2, self.relu),
             self.block1,
             self.block2,
-            nn.Sequential(self.block3, self.block4, self.block5, self.block6, self.block7,
-                          self.block8, self.block9, self.block10, self.block11),
+            nn.Sequential(
+                self.block3,
+                self.block4,
+                self.block5,
+                self.block6,
+                self.block7,
+                self.block8,
+                self.block9,
+                self.block10,
+                self.block11,
+            ),
             nn.Sequential(self.block12, self.conv3, self.bn3, self.relu, self.conv4, self.bn4),
         ]
 
@@ -49,18 +58,18 @@ class XceptionEncoder(Xception, EncoderMixin):
 
     def load_state_dict(self, state_dict):
         # remove linear
-        state_dict.pop('fc.bias', None)
-        state_dict.pop('fc.weight', None)
+        state_dict.pop("fc.bias", None)
+        state_dict.pop("fc.weight", None)
 
         super().load_state_dict(state_dict)
 
 
 xception_encoders = {
-    'xception': {
-        'encoder': XceptionEncoder,
-        'pretrained_settings': pretrained_settings['xception'],
-        'params': {
-            'out_channels': (3, 64, 128, 256, 728, 2048),
-        }
+    "xception": {
+        "encoder": XceptionEncoder,
+        "pretrained_settings": pretrained_settings["xception"],
+        "params": {
+            "out_channels": (3, 64, 128, 256, 728, 2048),
+        },
     },
 }
